@@ -23,7 +23,7 @@
 # Get fwts sources, strip out .git directory, add in necessary debian packaging
 # files, build source package ready for upload.
 #
-RELEASES="bionic focal jammy noble oracular plucky"
+RELEASES="bionic focal jammy noble oracular plucky questing"
 REPO=https://github.com/fwts/fwts
 RELEASE_TAR_URL=http://fwts.ubuntu.com/release
 FWTS=fwts
